Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4021)

Unified Diff: chrome/browser/ui/views/bookmarks/bookmark_bar_view.h

Issue 2477463003: Replace ui::AXViewState with AXNodeData and AXActionData (Closed)
Patch Set: Fix test Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
diff --git a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
index 9f0fb7f8c34dc993e09124738026794488289b49..c210bc6c0f8c99d68ab174e9dc1bdf96c1078993 100644
--- a/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
+++ b/chrome/browser/ui/views/bookmarks/bookmark_bar_view.h
@@ -180,7 +180,7 @@ class BookmarkBarView : public views::AccessiblePaneView,
void VisibilityChanged(View* starting_from, bool is_visible) override;
// AccessiblePaneView:
- void GetAccessibleState(ui::AXViewState* state) override;
+ void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
// gfx::AnimationDelegate:
void AnimationProgressed(const gfx::Animation* animation) override;
@@ -284,7 +284,7 @@ class BookmarkBarView : public views::AccessiblePaneView,
views::LabelButton* GetBookmarkButton(int index);
// Returns BOOKMARK_LAUNCH_LOCATION_DETACHED_BAR or
// BOOKMARK_LAUNCH_LOCATION_ATTACHED_BAR based on detached state.
BookmarkLaunchLocation GetBookmarkLaunchLocation() const;
// Returns the index of the first hidden bookmark button. If all buttons are
@@ -284,7 +284,7 @@ class BookmarkBarView : public views::AccessiblePaneView,
views::LabelButton* GetBookmarkButton(int index);
// Returns BOOKMARK_LAUNCH_LOCATION_DETACHED_BAR or
- // BOOKMARK_LAUNCH_LOCATION_ATTACHED_BAR based on detached state.
+ // BOOKMARK_LAUNCH_LOCATION_ATTACHED_BAR based on detached node_data.
BookmarkLaunchLocation GetBookmarkLaunchLocation() const;
// Returns the index of the first hidden bookmark button. If all buttons are

Powered by Google App Engine
This is Rietveld 408576698